@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 
 import numpy as np
-import pandas as pd
 import os
+import pandas as pd
+import smartsheet
 from sqlalchemy import create_engine
+from time import time
 from win32com.client import Dispatch
 
 """
@@ -72,7 +74,7 @@ else:
 file_production_data = os.path.split(file_project)[0]
     
 def get_sql_engine():
-    
+
     sql_username = os.environ['BARTERTOWN_USERNAME']
     sql_password = os.environ['BARTERTOWN_PASSWORD']
     
@@ -115,111 +117,79 @@ def save_df_existing_Excel_ALL (file_name_save, df_list_save, sheet_name_save):
     # Closes Excel
     xl.Quit()
 
-def get_df_keys():
-    df = pd.read_excel(os.path.join(file_project,'Python_Functions','Data Download Scripts','Fleet_database.xlsx'), sheetname='Data')
-    return df
+def get_ss_as_df(sheet_id, drop_col_1=True, start_col=None, index_col=None):
+    # helper function to query the data in a SS and put it into a dataframe
+    start = time()
 
-def get_ss_as_df(sheet_id):
-    # helper function to query the data in a SS and put it into a dataframme
-
-    # pip install smartsheet-python-sdk
-    import smartsheet
     # API_TOKEN is user-specific, so SS will block you from accessing 
     # sheets that you don't have permissions for
     API_TOKEN = os.environ['SMARTSHEET_TOKEN']
 
     # Initialize API client
     ss_client = smartsheet.Smartsheet(API_TOKEN)
+
     # by default, the SS functions will return error objects if you do something wrong 
     # (eg query a nonexistent sheet), instead of raising exceptions
     # if you ask me, that's crazy.  so we tell it to raise exceptions instead
     ss_client.errors_as_exceptions(True)
 
-    # page_size (rowcount) defaults to 100, which is annoying
-    # we want everything, so we have to get the number of rows in the sheet first
-    # set it to zero initially so we don't get a bunch of unnecessary data
-    sheet = ss_client.Sheets.get_sheet(sheet_id, page_size=0)
-    row_count = sheet.total_row_count
-    # now query the sheet again, using the actual row count
-    sheet = ss_client.Sheets.get_sheet(sheet_id, page_size=row_count)
+    cols = ss_client.Sheets.get_columns(sheet_id)
+    col_ids, colnames = zip(*((col.id, col.title) for col in cols.result[start_col:]))
+
+    # If an number is provided for the index col we'll find that index in the result list and assign it as the index
+    if isinstance(index_col, (int, float)):
+        index_col_id, index_colname = cols.result[index_col].id, cols.result[index_col].title
+    # If a string is provided for the index col we'll find that column name & assign it as the index
+    elif isinstance(index_col, str):
+        for col in cols.result:
+            if col.title == index_col:
+                index_col_id, index_colname = col.id, col.title
+
+    # Add index column to the col list if present
+    try:
+        col_ids = (index_col_id,) + col_ids
+        colnames = (index_colname,) + colnames
+    except NameError:
+        pass
+        
+    # Get sheet
+    sheet = ss_client.Sheets.get_sheet(sheet_id, column_ids=list(col_ids))
     
     # extract out the cell values into a df
-    sheet_dict = sheet.to_dict()
-    # nested list comprehensions?  woahhhh
-    values = [[cell.get('value', None) for cell in row['cells']] for row in sheet_dict['rows']]
-    # convert None to nan.  for some reason this was difficult to do with the final df
-    values = [[val if val is not None else np.nan for val in row] for row in values]
+    values = [[cell.value for cell in row.cells] for row in sheet.rows]
     df = pd.DataFrame(values)
-    
+
+    # Drop empty rows
     df = df.dropna(how='all')
+    # Fill empty values with np.nan
+    df = df.fillna(np.nan)
     
     # df has the data, but the column names are just numbers
-    df.columns = [col.title for col in sheet.get_columns(include_all = True).data]
+    df.columns = list(colnames)
+
     # bring the index over
-    #df.index = [int(i) for i in df['Column1']]  #often breaks
     df.index = range(len(df))
-    del df['Column1']
+    if drop_col_1:
+        del df['Column1']
     
-    return df
+    # Set index if provided
+    if index_col:
+        df = df.set_index(index_colname)
 
-#DUPLICATE CREATED BY SAURABH TO ADJUST FOR SSs THAT DO NOT HAVE A 'Column1' in them (e.g. EPC Allocation tracker')
-def get_ss_as_df_spa(sheet_id):
-    # helper function to query the data in a SS and put it into a dataframme
-
-    # pip install smartsheet-python-sdk
-    import smartsheet
-    # API_TOKEN is user-specific, so SS will block you from accessing 
-    # sheets that you don't have permissions for
-    API_TOKEN = os.environ['SMARTSHEET_TOKEN']
-
-    # Initialize API client
-    ss_client = smartsheet.Smartsheet(API_TOKEN)
-    # by default, the SS functions will return error objects if you do something wrong 
-    # (eg query a nonexistent sheet), instead of raising exceptions
-    # if you ask me, that's crazy.  so we tell it to raise exceptions instead
-    ss_client.errors_as_exceptions(True)
-
-    # page_size (rowcount) defaults to 100, which is annoying
-    # we want everything, so we have to get the number of rows in the sheet first
-    # set it to zero initially so we don't get a bunch of unnecessary data
-    sheet = ss_client.Sheets.get_sheet(sheet_id, page_size=0)
-    row_count = sheet.total_row_count
-    # now query the sheet again, using the actual row count
-    sheet = ss_client.Sheets.get_sheet(sheet_id, page_size=row_count)
-    
-    # extract out the cell values into a df
-    sheet_dict = sheet.to_dict()
-    # nested list comprehensions?  woahhhh
-    values = [[cell.get('value', None) for cell in row['cells']] for row in sheet_dict['rows']]
-    # convert None to nan.  for some reason this was difficult to do with the final df
-    values = [[val if val is not None else np.nan for val in row] for row in values]
-    df = pd.DataFrame(values)
-    
-    df = df.dropna(how='all')
-    
-    # df has the data, but the column names are just numbers
-    df.columns = [col.title for col in sheet.get_columns(include_all = True).data]
-    # bring the index over
-    #df.index = [int(i) for i in df['Column1']]
-    #del df['Column1']
-    
     return df
 
 
-    
-# df_keys SS ID
-sheet_id = '8659171076794244'
-all_df_keys = get_ss_as_df(sheet_id)
-all_df_keys.index = all_df_keys['Project']
-for col in ['PIS', 'FC']:
-    all_df_keys[col] = pd.to_datetime(all_df_keys[col])
-    
-df_keys = all_df_keys.loc[all_df_keys['Retired'] != True, :]
-
-#df_keys = get_df_keys()
-
-try:
-    sql_engine = get_sql_engine()
-except Exception as e:
-    print('SQL Engine failed to load')
+def get_df_keys(retired=False):
+    # df_keys SS ID
+    sheet_id = '8659171076794244'
+    all_df_keys = get_ss_as_df(sheet_id)
+    all_df_keys.index = all_df_keys['Project']
+    for col in ['PIS', 'FC']:
+        all_df_keys[col] = pd.to_datetime(all_df_keys[col])
+        
+    if not retired:
+        df_keys = all_df_keys.loc[all_df_keys['Retired'] != True, :]
+    else:
+        df_keys = all_df_keys
 
+    return df_keys
