@@ -4,6 +4,7 @@ import numpy as np
 import scipy.interpolate
 import datetime
 import math
+import s3fs
 import shapely.geometry as gs
 
 """
@@ -27,7 +28,14 @@ def timeseries(orig_df, df_index, lat, lon):
     df = df.loc[ df['dist'] < 200, : ]
     
     #filter unused columns via production data index    
-    date_cols = [x for x in orig_df.columns if (type(x) in [datetime.datetime, pd.Timestamp])]
+    # date_cols = [x for x in orig_df.columns if (type(x) in [datetime.datetime, pd.Timestamp])]
+    date_cols = []
+    for col in orig_df.columns:
+        try:
+            pd.to_datetime(col)
+            date_cols.append(col)
+        except:
+            continue
     df_index_dates = pd.to_datetime(list(set([x.date() for x in df_index])))
 
     
@@ -68,7 +76,7 @@ def timeseries(orig_df, df_index, lat, lon):
             Z0 = interp(X, Y)[0][0]
         else: 
             #Z0 = t_df.loc[t_df.dist.idxmin(), col] ##sometimes you get an array or a value?
-            Z0 = pd.np.median(t_df.loc[t_df.dist.idxmin(), col])
+            Z0 = np.median(t_df.loc[t_df.dist.idxmin(), col])
                 
         #Z.append(Z0[0][0])
         z_df.loc[col, 'snow'] = Z0
@@ -77,67 +85,8 @@ def timeseries(orig_df, df_index, lat, lon):
     #df.index = pd.date_range('2017-01-01', '2017-01-31')
     return z_df
 
-def coverage(df, snow_data):
-    POA = df['POA_avg']
-    Tamb = df['Tamb_avg']
-    
-    coverage = pd.Series(index = df.index)
-    coverage.iloc[0] = 0
-    m = -80
-    theta = 20 * 3.14159/180
-    for dt in df.index[0:-1]:
-        if dt.date() in snow_data.index:                                #prevents issues with first day not starting at midnight
-            snow = snow_data.loc[dt.date()].item()
-            snow_percent = np.min([snow / .01,1])
-            if dt.hour == 0 and (snow_data.loc[dt.date()] > 0).item():
-                coverage[dt] = snow_percent
-            if Tamb[dt] > POA[dt] / m:
-                coverage[dt] -= 0.197 * math.sin(theta)
-            coverage[dt + pd.Timedelta("1h")] = coverage[dt]
-    
-    coverage[coverage < 0] = 0
-    coverage.fillna(0)
-    return coverage
-
-
-#add in synthetic average temp data
-def coverage_v2(df, snow_data, aux):
-    #synthetic ambient data
-    #i personally don't think this equation makes sense practically. when tmod is greater than 0 and poa is very high, it puts ambient to sub zero
-    #aux = df['Tmod_avg'] - df['POA_avg'] *np.exp( a_module+ b_module*df['Wind_speed'])
-    
-    POA = df['POA_avg'].copy()
-    Tamb = df['Tamb_avg'].copy()
-    
-    #swap if necessary
-    Tamb.loc[Tamb == 0] = aux
-    
-    coverage = pd.Series(index = df.index)
-    coverage.iloc[0] = 0
-    m = -80
-    theta = 20 * 3.14159/180
-    for dt in df.index[0:-1]:
-        if dt.date() in snow_data.index:                                #prevents issues with first day not starting at midnight
-            snow = snow_data.loc[dt.date()].item()
-            snow_percent = np.min([snow / .01,1])
-            if dt.hour == 0 and (snow_data.loc[dt.date()] > 0).item():
-                if snow_percent > coverage[dt]:
-                    coverage[dt] = snow_percent
-            #this is the section that allows for melting. if Tamb is below 0 continuously, it never melts and uses previous coverage value
-            if Tamb[dt] > POA[dt] / m:
-                coverage[dt] -= 0.197 * math.sin(theta)
-            coverage[dt + pd.Timedelta("1h")] = coverage[dt]
-    
-    coverage[coverage < 0] = 0
-    coverage.fillna(0)
-    return coverage
-
-import s3fs
-bucket = 'perfdatadev.ccrenew.com'
-bucket_prefix_snow = "snow_projects/"
-
 #helper function to get data from s3
-def retrieve_df(key):
+def retrieve_df(bucket, key):
     path = "s3://{b}/{k}".format(b=bucket, k=key)
     try:
         df = pd.read_csv(path, index_col=0, parse_dates=True,header=None)
@@ -149,6 +98,9 @@ def retrieve_df(key):
 def coverage_v3(df, snow_data, aux,data_source,project_name):
     #take v2, but make the jan first value the same as the last value from previous year, if it exists
     
+    bucket = 'perfdatadev.ccrenew.com'
+    bucket_prefix_snow = "snow_projects/"
+
     POA = df['POA_avg'].copy()
     Tamb = df['Tamb_avg'].copy()
     
@@ -169,7 +121,7 @@ def coverage_v3(df, snow_data, aux,data_source,project_name):
     snow_key=bucket_prefix_snow+project_name+"/"+fname_data
 
 
-    cover_last=retrieve_df(snow_key)
+    cover_last=retrieve_df(bucket, snow_key)
     if len(cover_last)>0:
         try:
             coverage.loc['{}-01-01 00:00:00'.format(year)] #fail if the first isnt in the new year
@@ -182,10 +134,12 @@ def coverage_v3(df, snow_data, aux,data_source,project_name):
     m = -80
     theta = 20 * 3.14159/180
     for dt in df.index[0:-1]:
-        if dt.date() in snow_data.index:                                #prevents issues with first day not starting at midnight
-            snow = snow_data.loc[dt.date()].item()
+        # We'll get the date portion of the datetime to use for parsing the data
+        dt_date = dt.floor('d')
+        if dt_date in snow_data.index:                                #prevents issues with first day not starting at midnight
+            snow = snow_data.loc[dt_date].item()
             snow_percent = np.min([snow / .01,1])
-            if dt.hour == 0 and (snow_data.loc[dt.date()] > 0).item():
+            if dt.hour == 0 and (snow_data.loc[dt_date] > 0).item():
                 if snow_percent > coverage[dt]:
                     coverage[dt] = snow_percent
             #this is the section that allows for melting. if Tamb is below 0 continuously, it never melts and uses previous coverage value
