@@ -9,7 +9,7 @@ from numbers import Number
 import numpy as np
 from pandas import DataFrame, Series
 
-from ccrenew.dashboard.data_processing.CCR import all_df_keys as df_keys
+from ccrenew.dashboard import all_df_keys as df_keys
 
 logger = logging.getLogger(__name__)
 
